@@ -34,6 +34,7 @@ from typing import Optional
 from typing import Tuple
 
 import requests
+from loguru import logger
 from ruamel.yaml import YAML
 
 
@@ -131,7 +132,7 @@ def _simulation_execute_operation(
 ) -> str:
     """Generic method to launch API operation on a target simulation."""
 
-    print(
+    logger.info(
         "[+] Going to execute operation '{}' on simulation ID '{}'".format(
             operation, id_simulation
         )
@@ -157,8 +158,8 @@ def _simulation_execute_operation(
         # Sleep before next iteration
         time.sleep(2)
 
-        print(
-            "    [+] Currently executing operation '{}' on "
+        logger.info(
+            "  [+] Currently executing operation '{}' on "
             "simulation ID '{}'...".format(operation, id_simulation)
         )
 
@@ -175,12 +176,12 @@ def _simulation_execute_operation(
             # Operation has ended
             break
 
-    print(
+    logger.info(
         "[+] Operation '{}' on simulation ID '{}' was correctly executed".format(
             operation, id_simulation
         )
     )
-    print("[+] Current simulation status: '{}'".format(current_status))
+    logger.info("[+] Current simulation status: '{}'".format(current_status))
 
     return id_simulation
 
@@ -1102,7 +1103,7 @@ def snapshot_simulation(id_simulation: int) -> str:
 
     yaml: str = result.json()
 
-    print(f"[+] Starting the snapshot of simulation {id_simulation}...")
+    logger.info(f"[+] Starting the snapshot of simulation {id_simulation}...")
     while simulation_status(id_simulation) != "SNAPSHOT":
         time.sleep(1)
 
@@ -1114,10 +1115,10 @@ def snapshot_simulation(id_simulation: int) -> str:
                 "Error during simulation snapshot: '{}'".format(error_message)
             )
 
-    print("[+] Snapshot process has started")
+    logger.info("[+] Snapshot process has started")
 
     while simulation_status(id_simulation) != "RUNNING":
-        print("  [+] Snapshot in progress...")
+        logger.info("  [+] Snapshot in progress...")
         time.sleep(1)
 
         simulation_dict = fetch_simulation(id_simulation)
@@ -1140,3 +1141,42 @@ def virtclient_status() -> Any:
 
     simulation_dict = result.json()
     return simulation_dict
+
+
+def add_dns_entries(id_simulation: int, dns_entries: Dict[str, str]) -> str:
+    """Add volatile DNS entries to the current simulation. Volatile means that it is not
+    stored in database.
+
+    """
+
+    data = json.dumps(dns_entries)
+    result = _post(
+        f"/simulation/{id_simulation}/add_dns_entries",
+        data=data,
+        headers={"Content-Type": "application/json"},
+    )
+
+    if result.status_code != 200:
+        _handle_error(result, "Error while adding DNS entries")
+
+
+def generate_malicious_domains(algorithm: str = None, number: int = 1) -> List[str]:
+    """Generate and return a list of malicious domains."""
+
+    data_dict = {
+        "algorithm": algorithm,
+        "number": number,
+    }
+    data = json.dumps(data_dict)
+
+    result = _post(
+        "/topology/generate_malicious_domains",
+        data=data,
+        headers={"Content-Type": "application/json"},
+    )
+
+    if result.status_code != 200:
+        _handle_error(result, "Error while adding DNS entries")
+
+    domains = result.json()
+    return domains["domains"]
