@@ -392,15 +392,30 @@ def provisioning_execute_handler(args: Any) -> None:
 
     # Parameters
     id_simulation = args.id_simulation
-    provisioning_configuration_file = args.provisioning_configuration_file
+    machines_file = args.machines_file
+    provisioning_file = args.provisioning_file
     debug = args.debug_mode
+    wait = not args.provisioning_nowait
+    timeout = args.timeout
+
+    if (id_simulation is None and machines_file is None) or (
+        id_simulation is not None and machines_file is not None
+    ):
+        raise Exception(
+            "Either id_simulation parameter or machines_file parameter is expected in provisioning_execute API"
+        )
 
     try:
         provisioning_api.provisioning_execute(
-            id_simulation, provisioning_configuration_file, debug=debug
+            id_simulation=id_simulation,
+            machines_file=machines_file,
+            provisioning_file=provisioning_file,
+            debug=debug,
+            wait=wait,
+            timeout=timeout,
         )
     except Exception as e:
-        logger.info(f"Error during provisioning: '{e}'")
+        logger.error(f"Error during provisioning: '{e}'")
         sys.exit(1)
 
 
@@ -412,13 +427,23 @@ def provisioning_ansible_handler(args: Any) -> None:
 
     # Parameters
     id_simulation = args.id_simulation
-    provisioning_playbook_path = args.provisioning_playbook_path
+    machines_file = args.machines_file
+    playbook_path = args.provisioning_playbook_path
     provisioning_extra_vars = args.provisioning_extra_vars
     provisioning_target_roles = args.provisioning_target_roles
     provisioning_target_system_types = args.provisioning_target_system_types
     provisioning_target_operating_systems = args.provisioning_target_operating_systems
     provisioning_target_names = args.provisioning_target_names
     debug = args.debug_mode
+    wait = not args.provisioning_nowait
+    timeout = args.timeout
+
+    if (id_simulation is None and machines_file is None) or (
+        id_simulation is not None and machines_file is not None
+    ):
+        raise Exception(
+            "Either id_simulation parameter or machines_file parameter is expected in provisioning_ansible API"
+        )
 
     # TODO: check that only one target type is defined
 
@@ -444,14 +469,50 @@ def provisioning_ansible_handler(args: Any) -> None:
 
     try:
         provisioning_api.provisioning_ansible(
-            id_simulation,
-            provisioning_playbook_path,
+            id_simulation=id_simulation,
+            machines_file=machines_file,
+            playbook_path=playbook_path,
             extra_vars=provisioning_extra_vars,
             target_roles=provisioning_target_roles,
             target_system_types=provisioning_target_system_types,
             target_operating_systems=provisioning_target_operating_systems,
             target_names=provisioning_target_names,
             debug=debug,
+            wait=wait,
+            timeout=timeout,
+        )
+    except Exception as e:
+        error_msg = str(e)
+        error_msg = error_msg.replace("\\n", "\n")
+        logger.error(f"Error during provisioning: {error_msg}")
+        sys.exit(1)
+
+
+#
+# 'provisioning_inventory' related functions
+#
+def provisioning_inventory_handler(args: Any) -> None:
+    """Generate ansible inventory files."""
+
+    # Parameters
+    id_simulation = args.id_simulation
+    machines_file = args.machines_file
+    output_dir = args.output_inventory_dir
+    debug = args.debug_mode
+
+    if (id_simulation is None and machines_file is None) or (
+        id_simulation is not None and machines_file is not None
+    ):
+        raise Exception(
+            "Either id_simulation parameter or machines_file parameter is expected in provisioning_inventory API"
+        )
+
+    try:
+        provisioning_api.provisioning_inventory(
+            id_simulation=id_simulation,
+            machines_file=machines_file,
+            output_dir=output_dir,
+            debug=debug,
         )
     except Exception as e:
         error_msg = str(e)
@@ -460,6 +521,56 @@ def provisioning_ansible_handler(args: Any) -> None:
         sys.exit(1)
 
 
+#
+# 'provisioning_stop' related functions
+#
+def provisioning_stop_handler(args: Any) -> None:
+    """Stop provisioning currently running"""
+
+    # Parameters
+    task_id = args.task_id
+
+    print("[+] Stopping provisioning task with id '{}'".format(task_id))
+
+    try:
+        provisioning_api.provisioning_stop(task_id)
+        print("[+] Stopping done.")
+
+    except Exception as e:
+        error_msg = str(e)
+        error_msg = error_msg.replace("\\n", "\n")
+        print(f"[-] Error while stopping provisioning: {error_msg}")
+        sys.exit(1)
+
+
+#
+# 'provisioning_status' related functions
+#
+def provisioning_status_handler(args: Any) -> None:
+    """Status provisioning currently running"""
+
+    # Parameters
+    task_id = args.task_id
+
+    print("[+] Provisioning task status with id '{}'".format(task_id))
+
+    try:
+        result = provisioning_api.provisioning_status(task_id)
+        status = result["status"]
+        if status is None:
+            print(
+                f"[+] Status unknown, this task id doesn't exist or is finished: {task_id}"
+            )
+        else:
+            print(f"[+] Status: {status}")
+
+    except Exception as e:
+        error_msg = str(e)
+        error_msg = error_msg.replace("\\n", "\n")
+        print(f"[-] Error while provisioning status: {error_msg}")
+        sys.exit(1)
+
+
 #
 # 'scenario_play' simulation
 #
@@ -596,6 +707,12 @@ def simu_status_handler(args: Any) -> None:
                         )
                     else:
                         logger.info("      [+] admin account: None")
+                if node["type"] == "physical_machine":
+                    logger.info(
+                        "      [+] roles: {}".format(
+                            node["roles"],
+                        )
+                    )
                 elif node["type"] == "docker":
                     logger.info(
                         "      [+] node stats: {} Mo, {} core(s)".format(
@@ -646,7 +763,7 @@ def simu_domains_handler(args: Any) -> None:
         if len(domains_dict) == 0:
             logger.info("[+] No domains défined in this simulation")
         else:
-            logger.info("[+] Domains defined: ")
+            logger.info("[+] Domains defined:")
             for domain_name, ip_address in domains_dict.items():
                 logger.info(
                     "  [+] {}: {}".format(
@@ -655,10 +772,8 @@ def simu_domains_handler(args: Any) -> None:
                     )
                 )
     except Exception as e:
-        logger.info(f"Error when pausing simulation: '{e}'")
+        logger.info(f"Error when getting simulation domains: '{e}'")
         sys.exit(1)
-    else:
-        logger.info("Simulation paused")
 
 
 #
@@ -1362,15 +1477,43 @@ def main() -> None:
     )
     parser_provisioning_execute.set_defaults(func=provisioning_execute_handler)
     parser_provisioning_execute.add_argument(
-        "id_simulation", type=int, help="The simulation id"
+        "--id",
+        type=int,
+        action="store",
+        required=False,
+        dest="id_simulation",
+        help="The simulation id",
+    )
+    parser_provisioning_execute.add_argument(
+        "--machines",
+        action="store",
+        required=False,
+        dest="machines_file",
+        help="Input path of machines configuration (YAML format)",
     )
     parser_provisioning_execute.add_argument(
         "-c",
         action="store",
         required=True,
-        dest="provisioning_configuration_file",
+        dest="provisioning_file",
         help="Input path of provisioning configuration",
     )
+    parser_provisioning_execute.add_argument(
+        "--no-wait",
+        action="store_true",
+        default=False,
+        dest="provisioning_nowait",
+        help="Don't wait for the task to be done",
+    )
+    parser_provisioning_execute.add_argument(
+        "--timeout",
+        action="store",
+        type=int,
+        required=False,
+        default=10800,
+        dest="timeout",
+        help="Timeout of the provisioning task (default to 10800 seconds - 3 hours)",
+    )
 
     # 'provisioning_ansible' command
     parser_provisioning_ansible = subparsers.add_parser(
@@ -1378,7 +1521,19 @@ def main() -> None:
     )
     parser_provisioning_ansible.set_defaults(func=provisioning_ansible_handler)
     parser_provisioning_ansible.add_argument(
-        "id_simulation", type=int, help="The simulation id"
+        "--id",
+        type=int,
+        action="store",
+        required=False,
+        dest="id_simulation",
+        help="The simulation id",
+    )
+    parser_provisioning_ansible.add_argument(
+        "--machines",
+        action="store",
+        required=False,
+        dest="machines_file",
+        help="Input path of machines configuration (YAML format)",
     )
     parser_provisioning_ansible.add_argument(
         "-c",
@@ -1418,21 +1573,69 @@ def main() -> None:
         dest="provisioning_extra_vars",
         help="Variables for the ansible playbook(s)",
     )
-
-    # 'provisioning_websites' command
-    parser_provisioning_execute = subparsers.add_parser(
-        "provisioning_execute", help="Execute provisioning chronology for a simulation"
+    parser_provisioning_ansible.add_argument(
+        "--no-wait",
+        action="store_true",
+        default=False,
+        dest="provisioning_nowait",
+        help="Don't wait for the task to be done",
     )
-    parser_provisioning_execute.set_defaults(func=provisioning_execute_handler)
-    parser_provisioning_execute.add_argument(
-        "id_simulation", type=int, help="The simulation id"
-    )
-    parser_provisioning_execute.add_argument(
-        "-c",
+    parser_provisioning_ansible.add_argument(
+        "--timeout",
         action="store",
+        type=int,
+        required=False,
+        default=3600,
+        dest="timeout",
+        help="Timeout of the provisioning task (default to 3600 seconds - 1 hour)",
+    )
+
+    # 'provisioning_stop' command
+    parser_provisioning_stop = subparsers.add_parser(
+        "provisioning_stop", help="Stop provisioning_task"
+    )
+    parser_provisioning_stop.set_defaults(func=provisioning_stop_handler)
+    parser_provisioning_stop.add_argument(
+        "task_id", type=str, help="The provisioning task id"
+    )
+
+    # 'provisioning_status' command
+    parser_provisioning_status = subparsers.add_parser(
+        "provisioning_status", help="Status provisioning_task"
+    )
+    parser_provisioning_status.set_defaults(func=provisioning_status_handler)
+    parser_provisioning_status.add_argument(
+        "task_id", type=str, help="The provisioning task id"
+    )
+
+    # 'provisioning_inventory' command
+    parser_provisioning_inventory = subparsers.add_parser(
+        "provisioning_inventory",
+        help="Generate ansible inventory files from targets information",
+    )
+    parser_provisioning_inventory.set_defaults(func=provisioning_inventory_handler)
+    parser_provisioning_inventory.add_argument(
+        "--id",
+        type=int,
+        action="store",
+        required=False,
+        dest="id_simulation",
+        help="The simulation id",
+    )
+    parser_provisioning_inventory.add_argument(
+        "--machines",
+        action="store",
+        required=False,
+        dest="machines_file",
+        help="Input path of machines configuration (YAML format)",
+    )
+    parser_provisioning_inventory.add_argument(
+        "-o",
+        "--output",
+        type=str,
         required=True,
-        dest="provisioning_configuration_file",
-        help="Input path of provisioning configuration",
+        dest="output_inventory_dir",
+        help="Path to the output inventory directory that will be created",
     )
 
     # -----------------------
@@ -1461,7 +1664,7 @@ def main() -> None:
         action="store",
         required=False,
         dest="scenario_file_results",
-        help="Absolute name of scenario results (json format)",
+        help="Absolute name of scenario results (JSON format)",
     )
 
     parser_scenario_play.add_argument(
@@ -1505,6 +1708,19 @@ def main() -> None:
     # parameters)
     args = parser.parse_args(left_argv, args)
 
+    # If DEBUG mode, set environment variable and enrich logger (default logger config
+    # is in __init__.py) to add timestamp
+    if args.debug_mode:
+        os.environ["CR_DEBUG"] = "1"
+        logger.configure(
+            handlers=[
+                {
+                    "sink": sys.stdout,
+                    "format": "|<green>{time:HH:mm:ss}</green>|<level>{level: ^7}</level>| {message}",
+                }
+            ],
+        )
+
     args.func(args)
     sys.exit(0)
 
